# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.tenants_api import TenantsApi


class TestTenantsApi(unittest.TestCase):
    """TenantsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TenantsApi()

    def tearDown(self) -> None:
        pass

    def test_tenants_domains_create(self) -> None:
        """Test case for tenants_domains_create

        """
        pass

    def test_tenants_domains_destroy(self) -> None:
        """Test case for tenants_domains_destroy

        """
        pass

    def test_tenants_domains_list(self) -> None:
        """Test case for tenants_domains_list

        """
        pass

    def test_tenants_domains_partial_update(self) -> None:
        """Test case for tenants_domains_partial_update

        """
        pass

    def test_tenants_domains_retrieve(self) -> None:
        """Test case for tenants_domains_retrieve

        """
        pass

    def test_tenants_domains_update(self) -> None:
        """Test case for tenants_domains_update

        """
        pass

    def test_tenants_tenants_create(self) -> None:
        """Test case for tenants_tenants_create

        """
        pass

    def test_tenants_tenants_create_admin_group_create(self) -> None:
        """Test case for tenants_tenants_create_admin_group_create

        """
        pass

    def test_tenants_tenants_create_recovery_key_create(self) -> None:
        """Test case for tenants_tenants_create_recovery_key_create

        """
        pass

    def test_tenants_tenants_destroy(self) -> None:
        """Test case for tenants_tenants_destroy

        """
        pass

    def test_tenants_tenants_list(self) -> None:
        """Test case for tenants_tenants_list

        """
        pass

    def test_tenants_tenants_partial_update(self) -> None:
        """Test case for tenants_tenants_partial_update

        """
        pass

    def test_tenants_tenants_retrieve(self) -> None:
        """Test case for tenants_tenants_retrieve

        """
        pass

    def test_tenants_tenants_update(self) -> None:
        """Test case for tenants_tenants_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
